RELEASE(7)		    NetBSD Reference Manual		    RELEASE(7)

NAME
     release - layout of NetBSD releases and snapshots

DESCRIPTION
     This document describes the layout of NetBSD releases and snapshots.
     This layout should be consistent between FTP servers and CD-ROMs, except
     possibly the path that leads to the release hierarchy.

     In this document, the following special words have these definitions:

     <machine>	     The platform for which the release was built, correspond-
		     ing to the hw.machine sysctl variable, e.g.  i386 or
		     amiga.

     <machine_arch>  The architecture for which a particular installation set
		     was built, corresponding to the hw.machine_arch sysctl
		     variable, e.g.  i386 or m68k.

     <rel>	     The target release.

     All README files are descriptions of the various files in directories
     that have ``non-standard'' contents.

     All BSDSUM files are historic BSD checksums for the various files in that
     directory, in the format produced by the command: cksum -o 1 <file>.

     All CKSUM files are POSIX checksums for the various files in that direc-
     tory, in the format produced by the command: cksum <file>.

     All MD5 files are MD5 digests for the various files in that directory, in
     the format produced by the command: cksum -m <file>.

     All SYSVSUM files are historic AT&T System V UNIX checksums for the vari-
     ous files in that directory, in the format produced by the command: cksum
     -o 2 <file>.

     The MD5 digest is the safest checksum, followed by the POSIX checksum.
     The other two checksums are provided only to ensure that the widest pos-
     sible range of system can check the integrity of the release files.

     Files that end in .tgz are gzipped tar archives.  This is used in lieu of
     .tar.gz because the software used to download the sets may incorrectly
     auto-unpack files ending in .gz and to accomodate systems which only sup-
     port 3 character extensions to file names.

     All tar archives are relative to the target's / directory, and do not in-
     clude the leading ``/''.

     All compression of release files is to be performed with the command:
     gzip -9.

     The root of the release hierarchy is .../NetBSD-<rel>/<machine>/. For
     files which may be shared by all systems of the same <machine_arch>,
     (e.g. the games and xbase sets for m68k-based platforms), this hierarchy
     will have a second root of .../NetBSD-<rel>/<machine_arch>/ which will
     contain those files.  For files which are completely machine-independent
     (e.g. the xfont set), this hierarchy will have a third root of
     .../NetBSD-<rel>/mi/ which will contain those files.  Unless otherwise
     noted, all files may be symbolic links to common <machine_arch> or ma-
     chine-independent files located in their respective directory hierar-
     chies.

     SOURCE_DATE    a file containing the date, in UTC, of the source code
		    from which the release or snapshot was built, in the de-
		    fault format produced by the command: date -u

     INSTALL	    Installation notes, including complete descriptions of
		    files contained within the release hierarchy

     binary/	    system binaries

		    sets/      installation sets

			       BSDSUM

			       CKSUM

			       MD5

			       SYSVSUM

			       Split/	     installation sets split with the
					     split(1) command.	Note: split
					     installation sets may not be
					     available for all platforms.

					     BSDSUM

					     CKSUM

					     MD5

					     SYSVSUM

					     base.aa

					     base.ab

					     ...

			       base.tgz	     The base binary distribution.
					     This set contains the base NetBSD
					     utilities that are necessary for
					     the system to run and be minimal-
					     ly functional.  It includes
					     shared libraries for those archi-
					     tectures that support support
					     them.  This set excludes all
					     things listed in the sets de-
					     scribed below.

			       comp.tgz	     The compiler tools distribution.
					     This set contains the C and C++
					     compilers, assembler, linker,
					     other toolchain components, and
					     their manual pages.  It also in-
					     cludes the system include files
					     (/usr/include) , and the static
					     system libraries.

			       etc.tgz	     This set contains the system con-
					     figuration files that reside in
					     /etc and in several other places
					     throughout the file system hier-
					     archy.

			       games.tgz     This set includes the games and


					     their manual pages.

			       kern.tgz	     This set includes a generic ker-
					     nel.

			       man.tgz	     This set includes all of the man-
					     ual pages for the binaries and
					     other software contained in the
					     base set which are not included
					     in the other sets.

			       misc.tgz	     This set includes the system dic-
					     tionaries (which are rather
					     large), the typesettable document
					     set, and manual pages for other
					     architectures, which happen to be
					     installed from the source tree by
					     default.

			       text.tgz	     This set includes the NetBSD text
					     processing tools, including
					     groff(1),	all related programs,
					     and their manual pages.

			       xbase.tgz     This set includes the base X11
					     distribution, including manual
					     pages and shared libraries for
					     those architectures that support
					     them, and excluding everything
					     contained in the other X11 sets.

			       xcomp.tgz     This set includes the X11 include
					     files and static X11 libraries.

			       xcontrib.tgz  This set includes binaries and
					     manual pages for programs built
					     from the X11 ``contrib'' sources.

			       xfont.tgz     This set includes the X11 fonts.

			       xserver.tgz   This set includes the X servers
					     and manual pages for <machine>.
					     Note: this set may not be
					     available on some platforms.

		    kernel/    suitably named, gzipped kernels

			       BSDSUM

			       CKSUM

			       MD5

			       README

			       SYSVSUM

			       netbsd-GENERIC.gz  A kernel built from the
						  GENERIC kernel configuration
						  file.	 This is meant as an
						  example only; different
						  platforms may have differ-
						  ently named kernels.



		    security/  security-related system binaries

			       BSDSUM

			       CKSUM

			       MD5

			       SYSVSUM

			       Split/

					 BSDSUM

					 CKSUM

					 MD5

					 SYSVSUM

					 secr.aa

					 secr.ab

					 ...

			       secr.tgz	 This set contains executables which
					 are built from the ``src/domestic''
					 portion of the NetBSD source tree.
					 It can only be found on those sites
					 which carry the complete NetBSD dis-
					 tribution and can legally obtain it.
					 (Remember, because of United States
					 law, it may not be legal to dis-
					 tribute this set to locations outside
					 the United States and Canada.)

     installation/  installation helper items

		    diskimage/	disk images, for those platforms that provide
				them

				BSDSUM

				CKSUM

				MD5

				README

				SYSVSUM

				diskimage-rz25.gz

		    floppy/	floppy images, for those platforms that pro-
				vide them

				BSDSUM

				CKSUM

				MD5

				README


				SYSVSUM

				floppy-144.gz

		    miniroot/	miniroot images, for those platforms that pro-
				vide them

				BSDSUM

				CKSUM

				MD5

				README

				SYSVSUM

				miniroot.gz

		    misc/	miscellaneous installation helper utilities,
				including boot selectors, floppy writing soft-
				ware, other software that runs under foreign
				operating systems, etc.

				BSDSUM

				CKSUM

				MD5

				README

				SYSVSUM

				...

		    netboot/	network boot programs

				BSDSUM

				CKSUM

				MD5

				README

				SYSVSUM

				netboot.gz

		    tapeimage/	tape images, for those platforms that provide
				them

				BSDSUM

				CKSUM

				MD5

				README

				SYSVSUM

				tapeimage-hp9144.gz

SEE ALSO
     cksum(1),	date(1),  gzip(1),  split(1),  tar(1)

HISTORY
     The release manual page first appeared in NetBSD 1.3.

NetBSD			       November 18, 1997			     6
